aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/Window.h
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/core/Window.h')
-rw-r--r--arm_compute/core/Window.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/arm_compute/core/Window.h b/arm_compute/core/Window.h
index baf767e7d5..654f5ed4f8 100644
--- a/arm_compute/core/Window.h
+++ b/arm_compute/core/Window.h
@@ -157,10 +157,10 @@ public:
/** Use the tensor's dimensions to fill the window dimensions.
*
* @param[in] info Tensor information to copy the dimensions from.
* @param[in] first_dimension Only copy dimensions which are greater or equal to this value.
*/
- void use_tensor_dimensions(const ITensorInfo *info, size_t first_dimension = Window::DimX);
+ void use_tensor_dimensions(const TensorShape &shape, size_t first_dimension = Window::DimX);
/** Shift the values of a given dimension by the given shift_value
*
@@ -157,10 +157,10 @@ public:
/** Use the tensor's dimensions to fill the window dimensions.
*
- * @param[in] info Tensor information to copy the dimensions from.
+ * @param[in] shape @ref TensorShape to copy the dimensions from.
* @param[in] first_dimension Only copy dimensions which are greater or equal to this value.
*/